package com.jay.monitor.data.server.report;

import com.jay.monitor.data.core.model.serializable.base.BaseDTO;
import com.jay.monitor.data.server.enums.AlertRuleEnums;
import com.jay.monitor.data.server.models.dto.alert.RealTimeAlert;
import com.jay.monitor.data.server.report.alert.notify.AlertRealTimeMsg;
import com.jay.monitor.data.server.report.alert.rule.AlertRule;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Module 告警模块
 * @Description 实时告警模块
 * @Author liukaixiong
 * @Date 2021/1/14 10:35
 */
@Component
public class RealtimeAlertProcess {

    @Autowired(required = false)
    private List<AlertRule> alertRules;

    @Autowired(required = false)
    private List<AlertRealTimeMsg> realTimeMsgProcesses;

    private Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * 批量数据验证
     *
     * @param baseDTOList
     */
    public void process(List<? extends BaseDTO> baseDTOList) {

        if (this.alertRules == null || this.alertRules.size() == 0) {
            logger.debug("没有对应的匹配规则");
            return;
        }

        Map<AlertRuleEnums, List<RealTimeAlert>> baseGroupMap = new HashMap<>();

        for (int i = 0; i < baseDTOList.size(); i++) {
            BaseDTO baseDTO = baseDTOList.get(i);
            for (int j = 0; j < this.alertRules.size(); j++) {
                AlertRule alertRule = this.alertRules.get(j);
                if (alertRule.isTrigger(baseDTO)) {
                    RealTimeAlert realTimeAlert = new RealTimeAlert();
                    AlertRuleEnums alertRuleEnums = alertRule.ruleType();
                    List<RealTimeAlert> baseRuleList = baseGroupMap.get(alertRuleEnums);
                    if (baseRuleList == null) {
                        baseRuleList = new ArrayList<>();
                        baseGroupMap.put(alertRuleEnums, baseRuleList);
                    }
                    BeanUtils.copyProperties(baseDTO, realTimeAlert);
                    baseRuleList.add(realTimeAlert);
                    continue;
                }
            }
        }

        if (this.realTimeMsgProcesses != null && baseGroupMap.size() > 0) {
            this.realTimeMsgProcesses.forEach((alert) -> {
                baseGroupMap.forEach((k, v) -> {
                    alert.send(k, v);
                });
            });
        }
    }

}
