package com.jay.monitor.data.server.report.alert.notify;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.jay.monitor.data.server.costs.MdConstants;
import com.jay.monitor.data.server.enums.AlertMsgEnums;
import com.jay.monitor.data.server.enums.AlertRuleEnums;
import com.jay.monitor.data.server.models.config.AlertConfigModel;
import com.jay.monitor.data.server.models.dto.alert.RealTimeAlert;
import com.jay.monitor.data.server.models.request.dingding.ActionCardModel;
import com.jay.monitor.data.server.store.ConfigStoreManager;
import com.jay.monitor.data.server.utils.DingDingUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

/**
 * @Module 告警
 * @Description 实时告警
 * @Author liukaixiong
 * @Date 2021/1/14 13:25
 */
@Component
public class DingDingRealTimeAlertProcess implements AlertRealTimeMsg {

    @Autowired
    private ConfigStoreManager configStoreManager;

    @Override
    public AlertMsgEnums alertType() {
        return AlertMsgEnums.DingDing;
    }

    @Override
    public boolean send(AlertRuleEnums triggerRule, List<RealTimeAlert> msg) {
        AlertConfigModel alertConfigModel = configStoreManager.getAlertConfigModel(AlertMsgEnums.DingDing);
        String url = alertConfigModel.getUrl();
        String consoleUrl = configStoreManager.getConsoleUrl();
        String logMonitorUrl = configStoreManager.getLogMonitorUrl();

        msg.sort(Comparator.comparingLong(RealTimeAlert::getRequestTime).reversed());

        RealTimeAlert realTimeAlert = msg.get(0);
        realTimeAlert.setTriggerType(triggerRule);

        if (msg.size() > 1) {
            realTimeAlert.setTriggerCount(msg.size());
        }


        String logUrl = logMonitorUrl + realTimeAlert.getLogId();

        String object = JSON.toJSONString(realTimeAlert, SerializerFeature.PrettyFormat,
                SerializerFeature.WriteDateUseDateFormat, SerializerFeature.SkipTransientField);

        StringBuilder mdText = new StringBuilder();
        mdText.append("【[日志跳转明细](" + logUrl + ")】");
        mdText.append("\r【[控制台跳转明细](" + consoleUrl + ")】");
        mdText.append(MdConstants.newLine);
        mdText.append(" ``` ");
        mdText.append(MdConstants.newLine);
        mdText.append(object);
        mdText.append(MdConstants.newLine);

        List<ActionCardModel.ActionCardDTO.BtnsDTO> btnDTOList = Arrays.asList(new ActionCardModel.ActionCardDTO.BtnsDTO("查看日志", logUrl), new ActionCardModel.ActionCardDTO.BtnsDTO("控制台查看", consoleUrl));
        ActionCardModel actionCardModel = DingDingUtils.buildActionCardModel("jay - 实时告警", mdText.toString(), 0, btnDTOList);
        return DingDingUtils.send(url, actionCardModel);
    }
}
